==> owncloud_6.0.4~beta1%2Bdfsg.orig.tar.bz2: owncloud/apps/contacts/l10n/en_GB.php <==
<?php $TRANSLATIONS = array(
"Contacts" => "Contacts",
"Save" => "Save",
"Uploading..." => "Uploading...",
"Importing..." => "Importing...",
"Preparing..." => "Preparing...",
"Imported {count} of {total} contacts" => "Imported {count} of {total} contacts",
"Imported {imported} contacts. {failed} failed." => "Imported {imported} contacts. {failed} failed.",
"An address book called {name} already exists" => "An address book called {name} already exists",
"Failed adding address book: {error}" => "Failed adding address book: {error}",
"Failed loading address books: {error}" => "Failed loading address books: {error}",
"Indexing contacts" => "Indexing contacts",
"Unrecoverable error loading address books: {msg}" => "Unrecoverable error loading address books: {msg}",
"Error." => "Error.",
"Add to..." => "Add to...",
"Remove from..." => "Remove from...",
"Add group..." => "Add group...",
"Invalid URL: \"{url}\"" => "Invalid URL: \"{url}\"",
"There was an error opening a mail composer." => "There was an error opening a mail composer.",
"Invalid email: \"{url}\"" => "Invalid email: \"{url}\"",
"Merge failed. Cannot find contact: {id}" => "Merge failed. Cannot find contact: {id}",
"Merge failed." => "Merge failed.",
"Merge failed. Error saving contact." => "Merge failed. Error saving contact.",
"Select photo" => "Select photo",
"Network or server error. Please inform administrator." => "Network or server error. Please inform administrator.",
"Error adding to group." => "Error adding to group.",
"Error removing from group." => "Error removing from group.",
"Error setting {name} as favorite." => "Error setting {name} as favourite.",
"Merge contacts" => "Merge contacts",
"Cancel" => "Cancel",
"Add group" => "Add group",
"OK" => "OK",
"Could not find contact: {id}" => "Could not find contact: {id}",
"No files selected for upload." => "No files selected for upload.",
"The file you are trying to upload exceed the maximum size for file uploads on this server." => "The file you are trying to upload exceeds the maximum size for file uploads on this server.",
"Edit profile picture" => "Edit profile picture",
"Crop photo" => "Crop photo",
"Is this correct?" => "Is this correct?",
"Error parsing date: {date}" => "Error parsing date: {date}",
"# groups" => "# groups",
"Error parsing birthday {bday}: {error}" => "Error parsing birthday {bday}: {error}",
"Some contacts are marked for deletion, but not deleted yet. Please wait for them to be deleted." => "Some contacts are marked for deletion, but not deleted yet. Please wait for them to be deleted.",
"Click to undo deletion of {num} contacts" => "Click to undo deletion of {num} contacts",
"Cancelled deletion of {num} contacts" => "Cancelled deletion of {num} contacts",
"Add" => "Add",
"Contact is already in this group." => "Contact is already in this group.",
"Contacts are already in this group." => "Contacts are already in this group.",
"Couldn't get contact list." => "Couldn't get contact list.",
"Contact is not in this group." => "Contact is not in this group.",
"Contacts are not in this group." => "Contacts are not in this group.",
"Failed renaming group: {error}" => "Failed renaming group: {error}",
"A group named {group} already exists" => "A group named {group} already exists",
"You can drag groups to\narrange them as you like." => "You can drag groups to\narrange them as you like.",
"Failed adding group: {error}" => "Failed adding group: {error}",
"All" => "All",
"Favorites" => "Favourites",
"Shared by {owner}" => "Shared by {owner}",
"Not grouped" => "Not grouped",
"Failed loading groups: {error}" => "Failed loading groups: {error}",
"Please choose the addressbook" => "Please choose the address book",
"Import into..." => "Import into...",
"Error loading import template" => "Error loading import template",
"Import contacts" => "Import contacts",
"Import" => "Import",
"Import done" => "Import done",
"Close" => "Close",
"Error" => "Error",
"Displayname cannot be empty." => "Displayname cannot be empty.",
"Show CardDav link" => "Show CardDav link",
"Show read-only VCF link" => "Show read-only VCF link",
"Download" => "Download",
"Edit" => "Edit",
"Delete" => "Delete",
"More..." => "More...",
"Less..." => "Less...",
"Server error! Please inform system administator" => "Server error! Please inform a system administrator",
"Failed loading photo: {error}" => "Failed to load photo: {error}",
"You do not have permissions to see this contacts" => "You do not have permission to see these contacts",
"Contact not found" => "Contact not found",
"You do not have permissions to see these contacts" => "You do not have permission to see these contacts",
"You do not have permissions add contacts to the address book" => "You do not have permission add contacts to the address book",
"The backend for this address book does not support adding contacts" => "The backend for this address book does not support adding contacts",
"You do not have permissions to delete this contact" => "You do not have permission to delete this contact",
"The backend for this address book does not support deleting contacts" => "The backend for this address book does not support deleting contacts",
"Unknown error" => "Unknown error",
"The backend for this address book does not support updating" => "The backend for this address book does not support updating",
"You don't have permissions to update the address book." => "You don't have permission to update the address book.",
"You don't have permissions to delete the address book." => "You don't have permission to delete the address book.",
"Address book not found" => "Address book not found",
"You do not have permissions to see this contact" => "You do not have permission to see this contact",
"You do not have permissions to update this contact" => "You do not have permission to update this contact",
"The backend for this contact does not support updating it" => "The backend for this contact does not support updating it",
"This backend not support adding contacts" => "This backend not support adding contacts",
"Property not found" => "Property not found",
" Missing IM parameter for: " => " Missing IM parameter for: ",
"Unknown IM: " => "Unknown IM: ",
"{name}'s Birthday" => "{name}'s Birthday",
"Error creating address book" => "Error creating address book",
"Error updating address book" => "Error updating address book",
"You do not have permissions to delete the \"%s\" address book" => "You do not have permission to delete the \"%s\" address book",
"Error deleting address book" => "Error deleting address book",
"Error creating contact." => "Error creating contact.",
"Error deleting contact." => "Error deleting contact.",
"Error retrieving contact." => "Error retrieving contact.",
"Error saving contact." => "Error saving contact.",
"Error removing contact from other address book." => "Error removing contact from other address book.",
"Couldn't find contact." => "Couldn't find contact.",
"No contact data in request." => "No contact data in request.",
"Error merging into contact." => "Error merging into contact.",
"Error saving contact to backend." => "Error saving contact to backend.",
"Property name is not set." => "Property name is not set.",
"Property checksum is not set." => "Property checksum is not set.",
"Information about vCard is incorrect. Please reload the page." => "Information about vCard is incorrect. Please reload the page.",
"Error updating contact" => "Error updating contact",
"Error saving contact to backend" => "Error saving contact to backend",
"Error getting user photo" => "Error getting user photo",
"No file was uploaded. Unknown error" => "No file was uploaded. Unknown error",
"There is no error, the file uploaded with success" => "There is no error, the file uploaded successfully",
"The uploaded file exceeds the upload_max_filesize directive in php.ini" => "The uploaded file exceeds the upload_max_filesize directive in php.ini",
"The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" => "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form",
"The uploaded file was only partially uploaded" => "The uploaded file was only partially uploaded",
"No file was uploaded" => "No file was uploaded",
"Missing a temporary folder" => "Missing a temporary folder",
"Couldn't load temporary image: " => "Couldn't load temporary image: ",
"Couldn't save temporary image: " => "Couldn't save temporary image: ",
"No photo path was submitted." => "No photo path was submitted.",
"File doesn't exist:" => "File doesn't exist:",
"Error loading image." => "Error loading image.",
"Image has been removed from cache" => "Image has been removed from cache",
"Error creating temporary image" => "Error creating temporary image",
"Error cropping image" => "Error cropping image",
"Error resizing image" => "Error resizing image",
"Error getting PHOTO property." => "Error getting PHOTO property.",
"No group name given." => "No group name given.",
"Error adding group." => "Error adding group.",
"No group name to rename from given." => "No group name to rename from given.",
"No group name to rename to given." => "No group name to rename to given.",
"Error renaming group." => "Error renaming group.",
"Group ID missing from request." => "Group ID missing from request.",
"Group name missing from request." => "Group name missing from request.",
"Contact ID missing from request." => "Contact ID missing from request.",
"Failed to write to disk" => "Failed to write to disk",
"Not enough storage available" => "Not enough storage available",
"Attempt to upload blacklisted file:" => "Attempt to upload blacklisted file:",
"Error uploading contacts to storage." => "Error uploading contacts to storage.",
"Error moving file to imports folder." => "Error moving file to imports folder.",
"You do not have permissions to import into this address book." => "You do not have permission to import into this address book.",
"File name missing from request." => "File name missing from request.",
"Progress key missing from request." => "Progress key missing from request.",
"Attempt to access blacklisted file:" => "Attempt to access blacklisted file:",
"No contacts found in: " => "No contacts found in: ",
"No key is given." => "No key is given.",
"No value is given." => "No value is given.",
"Could not set preference: " => "Could not set preference: ",
"Contact" => "Contact",
"Other" => "Other",
"HomePage" => "HomePage",
"Jabber" => "Jabber",
"Internet call" => "Internet call",
"AIM" => "AIM",
"MSN" => "MSN",
"Twitter" => "Twitter",
"GoogleTalk" => "GoogleTalk",
"Facebook" => "Facebook",
"XMPP" => "XMPP",
"ICQ" => "ICQ",
"Yahoo" => "Yahoo",
"Skype" => "Skype",
"QQ" => "QQ",
"GaduGadu" => "GaduGadu",
"Work" => "Work",
"Home" => "Home",
"Mobile" => "Mobile",
"Text" => "Text",
"Voice" => "Voice",
"Message" => "Message",
"Fax" => "Fax",
"Video" => "Video",
"Pager" => "Pager",
"Internet" => "Internet",
"Friends" => "Friends",
"Family" => "Family",
"New Contact" => "New Contact",
"Group name" => "Group name",
"New Group" => "New Group",
"Address books" => "Address books",
"Display name" => "Display name",
"Add Address Book" => "Add Address Book",
"Select file..." => "Select file...",
"(De-)select all" => "(De-)select all",
"Sort order" => "Sort order",
"First- Lastname" => "Firstname Surname",
"Last-, Firstname" => "Surname, Firstname",
"Groups" => "Groups",
"Favorite" => "Favourite",
"Merge selected" => "Merge selected",
"Keyboard shortcuts" => "Keyboard shortcuts",
"Navigation" => "Navigation",
"Next contact in list" => "Next contact in list",
"Previous contact in list" => "Previous contact in list",
"Expand/collapse current addressbook" => "Expand/collapse current address book",
"Next addressbook" => "Next address book",
"Previous addressbook" => "Previous address book",
"Actions" => "Actions",
"Refresh contacts list" => "Refresh contacts list",
"Add new contact" => "Add new contact",
"Add new addressbook" => "Add new address book",
"Delete current contact" => "Delete current contact",
"<h3>You have no contacts in your address book or your address book is disabled.</h3><p>Add a new contact or import existing contacts from a VCF file.</p>" => "<h3>You have no contacts in your address book or your address book is disabled.</h3><p>Add a new contact or import existing contacts from a VCF file.</p>",
"Add contact" => "Add contact",
"Delete group" => "Delete group",
"Rename group" => "Rename group",
"Which contact should the data be merged into?" => "Into which contact should the data be merged?",
"Delete the other(s) after successful merge?" => "Delete the other(s) after successful merge?",
"Compose mail" => "Compose mail",
"Delete current photo" => "Delete current photo",
"Edit current photo" => "Edit current photo",
"Upload new photo" => "Upload new photo",
"Select photo from ownCloud" => "Select photo from ownCloud",
"Name" => "Name",
"First name" => "First-name",
"Additional names" => "Middle names",
"Last name" => "Surname",
"Select groups" => "Select groups",
"Select address book" => "Select address book",
"Nickname" => "Nickname",
"Enter nickname" => "Enter nickname",
"Title" => "Title",
"Enter title" => "Enter title",
"Organization" => "Organisation",
"Enter organization" => "Enter organisation",
"Birthday" => "Birthday",
"Notes go here..." => "Notes go here...",
"Export as VCF" => "Export as VCF",
"Add field..." => "Add field...",
"Phone" => "Phone",
"Email" => "Email",
"Instant Messaging" => "Instant Messaging",
"Address" => "Address",
"Note" => "Note",
"Web site" => "Website",
"Delete contact" => "Delete contact",
"Preferred" => "Preferred",
"Please specify a valid email address." => "Please specify a valid email address.",
"someone@example.com" => "someone@example.com",
"Mail to address" => "Mail to address",
"Delete email address" => "Delete email address",
"Enter phone number" => "Enter phone number",
"Delete phone number" => "Delete phone number",
"Go to web site" => "Go to website",
"Delete URL" => "Delete URL",
"View on map" => "View on map",
"Delete address" => "Delete address",
"1600 Pennsylvania Avenue, NW" => "1600 Pennsylvania Avenue, NW",
"Street address" => "Street address",
"20500" => "20500",
"Postal code" => "Postcode",
"Washington, DC" => "Washington, DC",
"City" => "City",
"District of Columbia" => "District of Columbia",
"State or province" => "State or province",
"USA" => "USA",
"Country" => "Country",
"Instant Messenger" => "Instant Messenger",
"Delete IM" => "Delete IM",
"Active" => "Active",
"Share" => "Share",
"Export" => "Export",
"CardDAV link" => "CardDAV link",
"CardDAV syncing addresses" => "CardDAV syncing addresses",
"more info" => "more info",
"Primary address (Kontact et al)" => "Primary address (Kontact et al)",
"iOS/OS X" => "iOS/OS X",
"Addressbooks" => "Address books",
"New Address Book" => "New Address Book",
"Description" => "Description"
);

==> owncloud_7.0.0~beta1%2Bdfsg.orig.tar.bz2: owncloud/apps/contacts/l10n/en_GB.php <==
<?php $TRANSLATIONS = array(
"Contacts" => "Contacts",
"Add new LDAP Addressbook" => "Add new LDAP address book",
"Ok" => "OK",
"Cancel" => "Cancel",
"Save" => "Save",
"Edit Addressbook" => "Edit address book",
"Starting file import" => "Starting file import",
"Format selected: {format}" => "Format selected: {format}",
"Automatic format detection" => "Automatic format detection",
"Processing {count}/{total} cards" => "Processing {count}/{total} cards",
"Total:{total}, Success:{imported}, Errors:{failed}" => "Total:{total}, Success:{imported}, Errors:{failed}",
"An address book called {name} already exists" => "An address book called {name} already exists",
"Failed adding address book: {error}" => "Failed adding address book: {error}",
"Failed loading address books: {error}" => "Failed loading address books: {error}",
"Server error! Please inform system administator" => "Server error! Please inform a system administrator",
"Indexing contacts" => "Indexing contacts",
"Unrecoverable error loading address books: {msg}" => "Unrecoverable error loading address books: {msg}",
"Error." => "Error.",
"Add to..." => "Add to...",
"Remove from..." => "Remove from...",
"Add group..." => "Add group...",
"Invalid URL: \"{url}\"" => "Invalid URL: \"{url}\"",
"Invalid email: \"{url}\"" => "Invalid email: \"{url}\"",
"Merge failed. Cannot find contact: {id}" => "Merge failed. Cannot find contact: {id}",
"Merge failed." => "Merge failed.",
"Merge failed. Error saving contact." => "Merge failed. Error saving contact.",
"Select photo" => "Select photo",
"Network or server error. Please inform administrator." => "Network or server error. Please inform administrator.",
"Only images can be used as contact photos" => "Only images can be used as contact photos",
"The size of \"{filename}\" exceeds the maximum allowed {size}" => "The size of \"{filename}\" exceeds the maximum allowed {size}",
"Error adding to group." => "Error adding to group.",
"Error removing from group." => "Error removing from group.",
"You have selected over 300 contacts.\nThis will most likely fail! Click here to try anyway." => "You have selected over 300 contacts.\nThis will most likely fail! Click here to try anyway.",
"Error setting {name} as favorite." => "Error setting {name} as favourite.",
"Merge contacts" => "Merge contacts",
"Add group" => "Add group",
"OK" => "OK",
"Could not find contact: {id}" => "Could not find contact: {id}",
"Edit profile picture" => "Edit profile picture",
"Crop photo" => "Crop photo",
"Error parsing date: {date}" => "Error parsing date: {date}",
"# groups" => "# groups",
"Error parsing birthday {bday}" => "Error parsing birthday {bday}",
"The backend does not support multi-byte characters." => "The backend does not support multi-byte characters.",
"Some contacts are marked for deletion, but not deleted yet. Please wait for them to be deleted." => "Some contacts are marked for deletion, but not deleted yet. Please wait for them to be deleted.",
"Click to undo deletion of {num} contacts" => "Click to undo deletion of {num} contacts",
"Cancelled deletion of {num} contacts" => "Cancelled deletion of {num} contacts",
"Add" => "Add",
"Contact is already in this group." => "Contact is already in this group.",
"Contacts are already in this group." => "Contacts are already in this group.",
"Couldn't get contact list." => "Couldn't get contact list.",
"Contact is not in this group." => "Contact is not in this group.",
"Contacts are not in this group." => "Contacts are not in this group.",
"A group named \"{group}\" already exists" => "A group named \"{group}\" already exists",
"Failed renaming group: {error}" => "Failed renaming group: {error}",
"You can drag groups to\narrange them as you like." => "You can drag groups to\narrange them as you like.",
"Failed adding group: {error}" => "Failed adding group: {error}",
"All" => "All",
"Favorites" => "Favourites",
"Shared by {owner}" => "Shared by {owner}",
"Not grouped" => "Not grouped",
"Failed loading groups: {error}" => "Failed loading groups: {error}",
"Please choose the addressbook" => "Please choose the address book",
"Import into..." => "Import into...",
"Error loading import template" => "Error loading import template",
"Import contacts" => "Import contacts",
"Import" => "Import",
"Importing..." => "Importing...",
"Import done" => "Import done",
"Close" => "Close",
"Error, missing parameters: " => "Error, missing parameters: ",
"Failed loading photo: {error}" => "Failed to load photo: {error}",
"You do not have permissions to see this contact" => "You do not have permission to see this contact",
"Contact not found" => "Contact not found",
"You do not have permissions to see these contacts" => "You do not have permission to see these contacts",
"You do not have permissions add contacts to the address book" => "You do not have permission add contacts to the address book",
"The backend for this address book does not support adding contacts" => "The backend for this address book does not support adding contacts",
"You do not have permissions to delete this contact" => "You do not have permission to delete this contact",
"The backend for this address book does not support deleting contacts" => "The backend for this address book does not support deleting contacts",
"Unknown error" => "Unknown error",
"Access denied" => "Access denied",
"The backend for this address book does not support updating" => "The backend for this address book does not support updating",
"You don't have permissions to delete the address book." => "You don't have permission to delete the address book.",
"Address book not found" => "Address book not found",
"You do not have permissions to update this contact" => "You do not have permission to update this contact",
"The backend for this contact does not support updating it" => "The backend for this contact does not support updating it",
"This backend does not support adding contacts" => "This backend does not support adding contacts",
"Property not found" => "Property not found",
" Missing IM parameter for: " => " Missing IM parameter for: ",
"Unknown IM: " => "Unknown IM: ",
"{name}'s Birthday" => "{name}'s Birthday",
"Error creating address book" => "Error creating address book",
"The \"%s\" backend does not support deleting address books" => "The \"%s\" backend does not support deleting address books",
"You do not have permissions to delete the \"%s\" address book" => "You do not have permission to delete the \"%s\" address book",
"Error deleting address book" => "Error deleting address book",
"Error creating contact." => "Error creating contact.",
"Error creating contact" => "Error creating contact",
"Error deleting contact" => "Error deleting contact",
"Error retrieving contact" => "Error retrieving contact",
"Error saving contact" => "Error saving contact",
"Error removing contact from other address book." => "Error removing contact from other address book.",
"Error getting moved contact" => "Error getting moved contact",
"Couldn't find contact." => "Couldn't find contact.",
"No contact data in request." => "No contact data in request.",
"Error merging into contact." => "Error merging into contact.",
"Error saving contact to backend." => "Error saving contact to backend.",
"Property name is not set." => "Property name is not set.",
"Property checksum is not set." => "Property checksum is not set.",
"Information about vCard is incorrect. Please reload the page." => "Information about vCard is incorrect. Please reload the page.",
"Error updating contact" => "Error updating contact",
"Error saving contact to backend" => "Error saving contact to backend",
"Error getting user photo" => "Error getting user photo",
"No photo path was submitted." => "No photo path was submitted.",
"Error loading image from cache" => "Error loading image from cache",
"Error getting PHOTO property." => "Error getting PHOTO property.",
"Error saving contact." => "Error saving contact.",
"No group name given." => "No group name given.",
"Error adding group." => "Error adding group.",
"No group name to rename from given." => "No group name to rename from given.",
"No group name to rename to given." => "No group name to rename to given.",
"Error renaming group." => "Error renaming group.",
"Group ID missing from request." => "Group ID missing from request.",
"Group name missing from request." => "Group name missing from request.",
"Contact ID missing from request." => "Contact ID missing from request.",
"No file was uploaded. Unknown error" => "No file was uploaded. Unknown error",
"There is no error, the file uploaded with success" => "There is no error, the file uploaded successfully",
"The uploaded file exceeds the upload_max_filesize directive in php.ini" => "The uploaded file exceeds the upload_max_filesize directive in php.ini",
"The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" => "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form",
"The uploaded file was only partially uploaded" => "The uploaded file was only partially uploaded",
"No file was uploaded" => "No file was uploaded",
"Missing a temporary folder" => "Missing a temporary folder",
"Failed to write to disk" => "Failed to write to disk",
"Not enough storage available" => "Not enough storage available",
"Attempt to upload blacklisted file:" => "Attempt to upload blacklisted file:",
"Error uploading contacts to storage." => "Error uploading contacts to storage.",
"Error moving file to imports folder." => "Error moving file to imports folder.",
"You do not have permissions to import into this address book." => "You do not have permission to import into this address book.",
"File name missing from request." => "File name missing from request.",
"Progress key missing from request." => "Progress key missing from request.",
"Attempt to access blacklisted file:" => "Attempt to access blacklisted file:",
"No key is given." => "No key is given.",
"No value is given." => "No value is given.",
"Could not set preference: " => "Could not set preference: ",
"Contact" => "Contact",
"Other" => "Other",
"HomePage" => "HomePage",
"Jabber" => "Jabber",
"Internet call" => "Internet call",
"AIM" => "AIM",
"MSN" => "MSN",
"Twitter" => "Twitter",
"GoogleTalk" => "GoogleTalk",
"Facebook" => "Facebook",
"XMPP" => "XMPP",
"ICQ" => "ICQ",
"Yahoo" => "Yahoo",
"Skype" => "Skype",
"QQ" => "QQ",
"GaduGadu" => "GaduGadu",
"ownCloud" => "ownCloud",
"Work" => "Work",
"Home" => "Home",
"Mobile" => "Mobile",
"Text" => "Text",
"Voice" => "Voice",
"Message" => "Message",
"Fax" => "Fax",
"Video" => "Video",
"Pager" => "Pager",
"Internet" => "Internet",
"Friends" => "Friends",
"Family" => "Family",
"Enable LDAP Backend" => "Enable LDAP backend",
"Enable LDAP backend for the contacts application" => "Enable LDAP backend for the contacts application",
"Warning: LDAP Backend is in beta mode, use with precautions" => "Warning: LDAP backend is in beta mode, use with caution",
"New contact" => "New contact",
"Group name" => "Group name",
"New group" => "New group",
"Address books" => "Address books",
"Display name" => "Display name",
"Add Address Book" => "Add Address Book",
"Add LDAP Address Book" => "Add LDAP address book",
"Automatic format" => "Automatic format",
"Select file..." => "Select file...",
"(De-)select all" => "(De-)select all",
"Sort order" => "Sort order",
"First- Lastname" => "Firstname Surname",
"Last-, Firstname" => "Surname, Firstname",
"Delete" => "Delete",
"Groups" => "Groups",
"Download" => "Download",
"Merge" => "Merge",
"Email" => "Email",
"Phone" => "Phone",
"Address" => "Address",
"Group" => "Group",
"Keyboard shortcuts" => "Keyboard shortcuts",
"Navigation" => "Navigation",
"Next contact in list" => "Next contact in list",
"Previous contact in list" => "Previous contact in list",
"Expand/collapse current addressbook" => "Expand/collapse current address book",
"Next addressbook" => "Next address book",
"Previous addressbook" => "Previous address book",
"Actions" => "Actions",
"Refresh contacts list" => "Refresh contacts list",
"Add new contact" => "Add new contact",
"Add new addressbook" => "Add new address book",
"Delete current contact" => "Delete current contact",
"You have no contacts in your address book or your address book is disabled." => "You have no contacts in your address book or your address book is disabled.",
"Add a new contact or import existing contacts from a VCF file." => "Add a new contact or import existing contacts from a VCF file.",
"Which contact should the data be merged into?" => "Into which contact should the data be merged?",
"Delete the other(s) after successful merge?" => "Delete the other(s) after successful merge?",
"Compose mail" => "Compose mail",
"Delete current photo" => "Delete current photo",
"Edit current photo" => "Edit current photo",
"Upload new photo" => "Upload new photo",
"Select photo from Files" => "Select photo from Files",
"Favorite" => "Favourite",
"Name" => "Name",
"First name" => "First-name",
"Additional names" => "Middle names",
"Last name" => "Surname",
"Address book" => "Address book",
"Nickname" => "Nickname",
"Title" => "Title",
"Organization" => "Organisation",
"Birthday" => "Birthday",
"Website" => "Website",
"Instant messaging" => "Instant messaging",
"Notes go here..." => "Notes go here...",
"Add field..." => "Add field...",
"Instant Messaging" => "Instant Messaging",
"Note" => "Note",
"Web site" => "Website",
"Preferred" => "Preferred",
"Please specify a valid email address." => "Please specify a valid email address.",
"someone@example.com" => "someone@example.com",
"Mail to address" => "Mail to address",
"Delete email address" => "Delete email address",
"Enter phone number" => "Enter phone number",
"Go to web site" => "Go to website",
"View on map" => "View on map",
"Street address" => "Street address",
"Postal code" => "Postcode",
"City" => "City",
"State or province" => "State or province",
"Country" => "Country",
"Instant Messenger" => "Instant Messenger",
"Active" => "Active",
"Share" => "Share",
"Export" => "Export",
"CardDAV link" => "CardDAV link",
"Edit" => "Edit",
"Addressbook URI" => "Address book URI",
"URI" => "URI",
"Description" => "Description",
"LDAP URL" => "LDAP URL",
"Anonymous" => "Anonymous",
"Read-only" => "Read-only",
"Read-Only" => "Read-only",
"User" => "User",
"Password" => "Password",
"Page size" => "Page size",
"Base DN for search" => "Base DN for search",
"Base DN" => "Base DN",
"Search filter" => "Search filter",
"Filter" => "Filter",
"Base DN for modification" => "Base DN for modification",
"Base DN modification" => "Base DN modification",
"Connector" => "Connector",
"Connector value (Better use external editor and copy/paste)" => "Connector value (Better use external editor and copy/paste)",
"Copy from (Warning, replaces current custom value)" => "Copy from (Warning, replaces current custom value)"
);
